summaryrefslogtreecommitdiffstats
path: root/Modules/_testcapimodule.c
diff options
context:
space:
mode:
Diffstat (limited to 'Modules/_testcapimodule.c')
-rw-r--r--Modules/_testcapimodule.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/Modules/_testcapimodule.c b/Modules/_testcapimodule.c
index 4a00fb1..15bd899 100644
--- a/Modules/_testcapimodule.c
+++ b/Modules/_testcapimodule.c
@@ -691,7 +691,7 @@ test_thread_state(PyObject *self, PyObject *args)
}
#endif
/* Some tests of PyString_FromFormat(). This needs more tests. */
static PyObject *
test_string_from_format(PyObject *self, PyObject *args)
{
@@ -699,10 +699,10 @@ test_string_from_format(PyObject *self, PyObject *args)
char *msg;
#define CHECK_1_FORMAT(FORMAT, TYPE) \
- result = PyString_FromFormat(FORMAT, (TYPE)1); \
+ result = PyBytes_FromFormat(FORMAT, (TYPE)1); \
if (result == NULL) \
return NULL; \
- if (strcmp(PyString_AsString(result), "1")) { \
+ if (strcmp(PyBytes_AsString(result), "1")) { \
msg = FORMAT " failed at 1"; \
goto Fail; \
} \
@@ -691,7 +691,7 @@ test_thread_state(PyObject *self, PyObject *args)
}
#endif
-/* Some tests of PyString_FromFormat(). This needs more tests. */
+/* Some tests of PyBytes_FromFormat(). This needs more tests. */
static PyObject *
test_string_from_format(PyObject *self, PyObject *args)